#
# spec file for package gpick
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define appname org.gpick.gpick
Name:           gpick
Version:        0.3
Release:        1.6
Summary:        Advanced color picker writen in GTK+
License:        BSD-3-Clause
Group:          Productivity/Graphics/Visualization/Other
URL:            http://www.gpick.org/
Source0:        https://github.com/thezbyg/gpick/releases/download/v%{version}/%{name}-%{version}.tar.gz
Source1:        copyright
# PATCH-FIX-UPSTREAM fix-boost-184.patch gh#thezbyg/gpick#227 smolsheep@opensuse.org -- Fix builds with boost
Patch1:         fix-boost-184.patch
# PATCH-FIX-UPSTREAM fix-version-check.patch gh#thezbyg/gpick#215 smolsheep@opensuse.org -- Fix path in build
Patch2:         fix-version-check.patch
# PATCH-FIX-UPSTREAM import-missing-scons.patch gh#thezbyg/gpick#216 smolsheep@opensuse.org -- Fix import of SCons
Patch3:         import-missing-scons.patch
# PATCH-FIX-UPSTREAM revert-cpp-lua.patch gh#thezbyg/gpick#217 smolsheep@opensuse.org -- Don't use nonexistant lua-c++
Patch4:         revert-cpp-lua.patch
BuildRequires:  boost-devel
BuildRequires:  expat
BuildRequires:  flex
BuildRequires:  gcc-c++
BuildRequires:  libboost_filesystem-devel
BuildRequires:  libboost_system-devel
BuildRequires:  libboost_test-devel
# hicolor-icon-theme BuildRequires for directory ownership
BuildRequires:  hicolor-icon-theme
BuildRequires:  cmake
BuildRequires:  libexpat-devel
BuildRequires:  pkgconfig
BuildRequires:  ragel
BuildRequires:  scons
%if 0%{?suse_version}
BuildRequires:  update-desktop-files
%endif
BuildRequires:  pkgconfig(dbus-glib-1)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(lua) >= 5.3

%description
Gpick is a featured color picker with palette creation and modification
tools. It is written in C++ and uses GTK+ toolkit for user interface.

%lang_package

%prep
%autosetup -p1

%build
export CFLAGS="%optflags"
export CXXFLAGS="%optflags"
%cmake
%cmake_build

%check
./build/tests

%install
export CFLAGS="%optflags"
export CXXFLAGS="%optflags"
%cmake_install
%if 0%{?suse_version}
%suse_update_desktop_file %{appname} Viewer
%endif
# Install copyright file. This file was given to me by the author/upstream.
cp %{SOURCE1} COPYRIGHT
%find_lang %{name} %{?no_lang_C}

%if 0%{?suse_version} && 0%{?suse_version} < 1330
%post
%icon_theme_cache_post

%postun
%icon_theme_cache_postun
%endif

%if 0%{?fedora_version}

%post
touch --no-create %{_datadir}/icons/hicolor &>/dev/null || :

%postun
if [ $1 -eq 0 ] ; then
    touch --no-create %{_datadir}/icons/hicolor &>/dev/null
    gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :
fi

%posttrans
gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :
%endif

%files
%defattr(-,root,root)
%doc COPYRIGHT
%{_bindir}/%{name}
%{_datadir}/applications/%{appname}.desktop
%{_datadir}/metainfo/%{appname}.metainfo.xml
%{_datadir}/mime/packages/%{appname}.xml
%{_datadir}/%{name}/
%{_datadir}/doc/%{name}/
%{_datadir}/icons/hicolor/*/*/%{name}.*
%{_mandir}/man1/%{name}.*

%files lang -f %{name}.lang

%changelog
* Thu Jun 13 2024 Joshua Smith <smolsheep@opensuse.org>
- Switch to CMake
- Enable tests
- Remove patches that are fixed upstream:
  * 0001-build-support-scons-python3.patch
  * reproducible.patch
- Add fix-boost-184.patch: Fix builds with boost 184
  (gh#thezbyg/gpick#227)
- Add fix-version-check.patch: Fix path in build
  (gh#thezbyg/gpick#215)
- Add import-missing-scons.patch: Fix import of SCons in SConscript
  (gh#thezbyg/gpick#216)
- Add revert-cpp-lua.patch: Use system lua-c instead of lua-c++
  (gh#thezbyg/gpick#217)
- Update to 0.3:
  Bug Fixes
  * Fix layout switching
  * Prevent wrong data directory selection
  * Fix crash due to zero-length string access
  Features
  * Add alpha channel support
  * Add additional converters
* Thu Feb  8 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Prepare for RPM 4.20: use autosetup.
* Thu Jan 30 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Mon Jun  4 2018 meissner@suse.com
- build with RPM_OPT_FLAGS
* Mon Nov 20 2017 dimstar@opensuse.org
- Add 0001-build-support-scons-python3.patch: Support scons running
  with python3 as interpreter.
- Conditionalize the openSUSE post/postun scripts for suse_version
  < 1330 only: newer versions handle the icon theme cache by means
  of file triggers.
* Wed Feb  1 2017 adam.majer@suse.de
- Use individual libboost-*-devel packages instead of boost-devel.
  + Add conditional libboost_headers-devel BuildRequires.
* Fri Jan 20 2017 zaitor@opensuse.org
- Update Url to new home.
* Tue Jan 17 2017 bwiedemann@suse.com
- Add reproducible.patch to allow for reproducible builds
  (gh#thezbyg/gpick#138).
* Mon Sep 23 2013 dimstar@opensuse.org
- Don't lie about the required lua version: SCons checks for
  version 5.2.
* Sat Mar 30 2013 dimstar@opensuse.org
- Update to version 0.2.5:
  + Bug fixes.
  + Translations support.
- Split out new -lang package.
- Add libexpat-devel BuildRequires: new dependency.
- Pass LOCALEDIR=%%{_datadir} to scons.
* Thu Oct 11 2012 cfarrell@suse.com
- license update: BSD-3-Clause
  summarize licenses - bulk are BSD-3-Clause
* Fri May 27 2011 vuntz@opensuse.org
- Correctly use %%suse_update_desktop_file by not re-installing
  .desktop file, and not replacing categories while we just need to
  add one category.
- Minor improvement to description.
* Mon May 16 2011 nmarques@opensuse.org
- Update to version 0.2.4:
  + Bug fix release only
- Drop gpick-no-return-in-non-void.patch, 01_expat_dependency.patch
  and 02_dsolink_expat.patch: fixed upstream
- BuildRequire pkgconfig instead of pkg-config (this is provided
  cross distro)
* Sat May  7 2011 nmarques@opensuse.org
- Updated source package to experimental 'amalgamation' package
  provided by upstream for testing
  + Removed lemon parser dependency (source includes now the
    generated files)
- Add _smp_mflags to scons call in build section
- BuildRequire expat
- Add 'COPYRIGHT' file with the licences, provided by upstream
- Add patches:
  + gpick-no-return-in-non-void.patch: adds missing return to
    non-void function (sent upstream);
  + Add 01_expat_dependency.patch: Adds expat dependency
  + Add 02_dsolink_expat.patch: fixes linking with expat.
* Thu May  5 2011 nmarques@opensuse.org
- Modified spec file with required stuff for Fedora builds.
* Thu May  5 2011 nmarques@opensuse.org
- Initial package from version 0.2.3
